export interface CacheParams {
    itemLifetime: number;
    monitoringFrequency: number;
    waiterTimeout: number;
    waiterFrequency: number;
}
export interface CacheItem<T> {
    id: string;
    value: T | null;
    createdAt: number;
    fetcher: () => Promise<T>;
    reserved: boolean;
}
export declare type Fetcher<T> = () => Promise<T>;
export default class Cache<T> {
    cache: Map<string, CacheItem<T>>;
    cacheLifetime: number;
    monitoringFrequency: number;
    waiterTimeout: number;
    waiterFrequency: number;
    isMonitoring: boolean;
    constructor({ itemLifetime, monitoringFrequency, waiterTimeout, waiterFrequency }: CacheParams);
    private runMonitor;
    private isExpired;
    private getItem;
    private reserveWaiter;
    private reserveAndFetch;
    getItemWithWait({ id, fetcher }: {
        id: string;
        fetcher: Fetcher<T>;
    }): Promise<any>;
    private reserveItem;
    private setItem;
}
